.. _spkg_marimo_jupyter_extension:

marimo_jupyter_extension: Jupyter extension to proxy marimo with JupyterLab integration
=======================================================================================

Description
-----------

Jupyter extension to proxy marimo with JupyterLab integration

License
-------

Upstream Contact
----------------

https://pypi.org/project/marimo-jupyter-extension/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_marimo`

Version Information
-------------------

requirements.txt::

    marimo-jupyter-extension

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install marimo-jupyter-extension

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i marimo_jupyter_extension


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
